@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-"""Bot client dedicated to Shodan.
+"""Bot dedicated to Shodan.
 
 """
 from tinyscript.helpers.data.types import is_domain, is_email
@@ -12,7 +12,7 @@ __all__ = ["ShodanBot"]
 
 class ShodanBot(ShodanAPI):
     """
-    ShodanBot class for requesting multiple information using the Shodan API.
+    Class for requesting multiple information using the Shodan API.
 
     :param apikey: API key
     :param args:   JSONBot / API arguments
